==> cherry_flutter-0.0.2.tar.gz: lib/widgets/button/chf_button.dart <==
import 'package:flutter/material.dart';

class ButtonConfig {
  static double height = 40.0;
  static double radius = 2.0;
  static double opacity = 0.7;
  static double fontSize = 14.0;
  static double loadingSize = 14.0;
  static double loadingSpace = 5.0;
  static double loadingStrokeWidth = 1.0;
  static double hairLine = 1.0;
  static Color defaultFontColor = const Color(0xff999999);
  static Color defaultColor = Colors.transparent;
  static Color plainBackgroundColor = Colors.transparent;
}

/// Date: 2021/5/20
/// button
/// Author: Create by Cherry
class CHFButton extends StatelessWidget {
  // 宽
  final double? width;

  // 高
  final double? height;

  // 内容
  final dynamic content;

  // 加载中
  final bool loading;

  // 禁用
  final bool disabled;

  // 朴素按钮
  final bool plain;

  // 朴素按钮背景
  final Color? plainBackgroundColor;

  // 矩形
  final bool rect;

  // 颜色
  final dynamic color;

  // icon图标
  final Widget? icon;

  // border粗细
  final double? hairline;

  // 字体大小
  final double? fontSize;

  // 文字颜色
  final Color? textColor;

  // 文字style
  final TextStyle? style;

  // shadow阴影
  final List<BoxShadow>? boxShadow;

  // 圆角
  final BorderRadius? borderRadius;

  // callback
  final GestureTapCallback? onTap;

  const CHFButton({
    Key? key,
    this.width,
    this.height,
    this.content,
    this.loading: false,
    this.disabled: false,
    this.plain: false,
    this.rect: false,
    this.color,
    this.plainBackgroundColor,
    this.icon,
    this.hairline,
    this.fontSize,
    this.textColor,
    this.style,
    this.boxShadow,
    this.borderRadius,
    this.onTap,
  }) : super(key: key);

  Widget render(BuildContext context) {
    late Widget _child;
    Color? backgroundColor;
    Color? buttonTextColor;
    Color? borderColor;
    borderColor =
        color is Gradient ? null : (color ?? ButtonConfig.defaultFontColor);
    backgroundColor = color is Gradient
        ? null
        : plain
            ? plainBackgroundColor ?? ButtonConfig.plainBackgroundColor
            : (color ?? ButtonConfig.defaultColor);
    buttonTextColor = textColor ??
        (plain
            ? borderColor
            : color != null
                ? Colors.white
                : ButtonConfig.defaultFontColor);
    if (content is String) {
      _child = Text(
        content,
        style: style ??
            TextStyle(
              fontSize: fontSize ?? ButtonConfig.fontSize,
              color: buttonTextColor,
            ),
      );
    } else if (content is Widget) {
      _child = content;
    } else {
      _child = SizedBox();
    }
    double _loadingSize = fontSize ?? ButtonConfig.loadingSize;
    return Container(
      width: width,
      height: height ?? ButtonConfig.height,
      child: Row(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          loading
              ? Container(
                  width: _loadingSize,
                  height: _loadingSize,
                  margin: EdgeInsets.only(right: ButtonConfig.loadingSpace),
                  child: CircularProgressIndicator(
                    valueColor: AlwaysStoppedAnimation(buttonTextColor),
                    backgroundColor: backgroundColor,
                    strokeWidth: ButtonConfig.loadingStrokeWidth,
                  ),
                )
              : icon != null
                  ? icon!
                  : Container(),
          _child
        ],
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    Color? borderColor;
    Color? backgroundColor;
    borderColor = color is Gradient
        ? null
        : (color ??
            (plain
                ? ButtonConfig.defaultFontColor
                : ButtonConfig.defaultColor));
    backgroundColor = color is Gradient
        ? null
        : plain
            ? plainBackgroundColor ?? ButtonConfig.plainBackgroundColor
            : (color ?? ButtonConfig.defaultColor);
    return Opacity(
      opacity: disabled ? ButtonConfig.opacity : 1.0,
      child: DecoratedBox(
        decoration: BoxDecoration(
            color: backgroundColor,
            gradient: color is Gradient ? color : null,
            borderRadius: borderRadius ??
                (rect ? null : BorderRadius.circular(ButtonConfig.radius)),
            border: color is Gradient
                ? null
                : Border.all(
                    width: hairline ?? ButtonConfig.hairLine,
                    color: borderColor!,
                  ),
            boxShadow: boxShadow),
        child: Material(
          type: MaterialType.transparency,
          child: InkWell(
            focusColor: (disabled || loading)
                ? Colors.transparent
                : Theme.of(context).focusColor,
            highlightColor: (disabled || loading)
                ? Colors.transparent
                : Theme.of(context).highlightColor,
            hoverColor: (disabled || loading)
                ? Colors.transparent
                : Theme.of(context).hoverColor,
            splashColor: (disabled || loading)
                ? Colors.transparent
                : Theme.of(context).splashColor,
            onTap: () {
              if (!disabled && !loading && onTap != null) onTap!.call();
            },
            borderRadius:
                borderRadius ?? BorderRadius.circular(ButtonConfig.radius),
            child: render(context),
          ),
        ),
      ),
    );
  }
}

==> cherry_flutter-0.0.3.tar.gz: lib/widgets/button/chf_button.dart <==
import 'package:flutter/material.dart';

class ButtonConfig {
  static double height = 40.0;
  static double radius = 2.0;
  static double opacity = 0.7;
  static double fontSize = 14.0;
  static FontWeight fontWeight = FontWeight.normal;
  static double loadingSize = 14.0;
  static double loadingSpace = 5.0;
  static double loadingStrokeWidth = 1.0;
  static double hairLine = 1.0;
  static Color defaultFontColor = const Color(0xff999999);
  static Color defaultColor = Colors.transparent;
  static Color plainBackgroundColor = Colors.transparent;
}

/// Date: 2021/5/20
/// button
/// Author: Create by Cherry
class CHFButton extends StatelessWidget {
  // 宽
  final double? width;

  // 高
  final double? height;

  // 内容
  final dynamic content;

  // 加载中
  final bool loading;

  // 禁用
  final bool disabled;

  // 朴素按钮
  final bool plain;

  // 朴素按钮背景
  final Color? plainBackgroundColor;

  // 矩形
  final bool rect;

  // 颜色
  final dynamic color;

  // icon图标
  final Widget? icon;

  // border粗细
  final double? hairline;

  // 字体大小
  final double? fontSize;

  // 文字颜色
  final Color? textColor;

  // 字体重量
  final FontWeight? fontWeight;

  // 文字style
  final TextStyle? style;

  // shadow阴影
  final List<BoxShadow>? boxShadow;

  // 圆角
  final BorderRadius? borderRadius;

  // 圆角值
  final double? radius;

  // callback
  final GestureTapCallback? onTap;

  const CHFButton({
    Key? key,
    this.width,
    this.height,
    this.content,
    this.loading: false,
    this.disabled: false,
    this.plain: false,
    this.rect: false,
    this.color,
    this.plainBackgroundColor,
    this.icon,
    this.hairline,
    this.fontSize,
    this.textColor,
    this.fontWeight,
    this.style,
    this.boxShadow,
    this.borderRadius,
    this.radius,
    this.onTap,
  }) : super(key: key);

  Widget render(BuildContext context) {
    late Widget _child;
    Color? backgroundColor;
    Color? buttonTextColor;
    Color? borderColor;
    borderColor =
        color is Gradient ? null : (color ?? ButtonConfig.defaultFontColor);
    backgroundColor = color is Gradient
        ? null
        : plain
            ? plainBackgroundColor ?? ButtonConfig.plainBackgroundColor
            : (color ?? ButtonConfig.defaultColor);
    buttonTextColor = textColor ??
        (plain
            ? borderColor
            : color != null
                ? Colors.white
                : ButtonConfig.defaultFontColor);
    if (content is String) {
      _child = Text(
        content,
        style: style ??
            TextStyle(
              fontSize: fontSize ?? ButtonConfig.fontSize,
              color: buttonTextColor,
              fontWeight: fontWeight ?? ButtonConfig.fontWeight,
            ),
      );
    } else if (content is Widget) {
      _child = content;
    } else {
      _child = SizedBox();
    }
    double _loadingSize = fontSize ?? ButtonConfig.loadingSize;
    return Container(
      width: width,
      height: height ?? ButtonConfig.height,
      child: Row(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          loading
              ? Container(
                  width: _loadingSize,
                  height: _loadingSize,
                  margin: EdgeInsets.only(right: ButtonConfig.loadingSpace),
                  child: CircularProgressIndicator(
                    valueColor: AlwaysStoppedAnimation(buttonTextColor),
                    backgroundColor: backgroundColor,
                    strokeWidth: ButtonConfig.loadingStrokeWidth,
                  ),
                )
              : icon != null
                  ? icon!
                  : Container(),
          _child
        ],
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    Color? borderColor;
    Color? backgroundColor;
    borderColor = color is Gradient
        ? null
        : (color ??
            (plain
                ? ButtonConfig.defaultFontColor
                : ButtonConfig.defaultColor));
    backgroundColor = color is Gradient
        ? null
        : plain
            ? plainBackgroundColor ?? ButtonConfig.plainBackgroundColor
            : (color ?? ButtonConfig.defaultColor);
    return Opacity(
      opacity: disabled ? ButtonConfig.opacity : 1.0,
      child: DecoratedBox(
        decoration: BoxDecoration(
            color: backgroundColor,
            gradient: color is Gradient ? color : null,
            borderRadius: borderRadius ??
                (rect ? null : BorderRadius.circular(ButtonConfig.radius)),
            border: color is Gradient
                ? null
                : Border.all(
                    width: hairline ?? ButtonConfig.hairLine,
                    color: borderColor!,
                  ),
            boxShadow: boxShadow),
        child: Material(
          type: MaterialType.transparency,
          child: InkWell(
            focusColor: (disabled || loading)
                ? Colors.transparent
                : Theme.of(context).focusColor,
            highlightColor: (disabled || loading)
                ? Colors.transparent
                : Theme.of(context).highlightColor,
            hoverColor: (disabled || loading)
                ? Colors.transparent
                : Theme.of(context).hoverColor,
            splashColor: (disabled || loading)
                ? Colors.transparent
                : Theme.of(context).splashColor,
            onTap: () {
              if (!disabled && !loading && onTap != null) onTap!.call();
            },
            borderRadius: borderRadius ??
                BorderRadius.circular(radius ?? ButtonConfig.radius),
            child: render(context),
          ),
        ),
      ),
    );
  }
}
